#image_handling
 
Description.
The package image_handling is used to:
    Processing:
       - Histogram matching
       - Structural similary
       - Resize image
    Utils:
       - Read image
       - Save image
       - Plot image
       - Plot result
       - Plot histogram
 
## Installation
 
Use the package manager[pip](https://pip.pypa.io/en/stable/) to install package_name
 
```bash
pip install image_handling
 
## Author
Adenias
 
## License
[MIT](https://choosealicense.com/licenses/mit/)
